netapp_ontap.models.security_key_manager_external API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.security_key_manager_external`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class SecurityKeyManagerExternalSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SecurityKeyManagerExternal object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `client_certificate: SecurityCertificate GET POST PATCH`

    The client_certificate field of the security_key_manager_external.

  `server_ca_certificates: List[SecurityCertificate] GET POST PATCH`

    The array of certificates that are common for all the keyservers per SVM.

  `servers: List[KeyServerReadcreate] GET POST`

    The set of external key servers.